@@ -168,7 +168,7 @@ private Q_SLOTS:
         const QJsonArray arr = obj[QLatin1String("modes")].toArray();
         QCOMPARE(arr.size(), output->modes().count());
 
-        const QJsonObject pos = obj[QLatin1String("pos")].toObject();
+        QJsonObject pos = obj[QLatin1String("pos")].toObject();
         QCOMPARE(pos[QLatin1String("x")].toInt(), output->pos().x());
         QCOMPARE(pos[QLatin1String("y")].toInt(), output->pos().y());
         const QJsonObject size = obj[QLatin1String("size")].toObject();
