@@ -126,7 +126,7 @@ void WaylandOutput::updateKScreenOutput(KScreen::OutputPtr &output)
     output->setEnabled(m_output->enabled() == KWayland::Client::OutputDevice::Enablement::Enabled);
     output->setConnected(true);
     output->setPrimary(true); // FIXME: wayland doesn't have the concept of a primary display
-    output->setName(m_output->model());
+    output->setName(name());
     // Physical size
     output->setSizeMm(m_output->physicalSize());
     output->setPos(m_output->globalPosition());
@@ -148,7 +148,8 @@ void WaylandOutput::updateKScreenOutput(KScreen::OutputPtr &output)
         }
 
         mode->setId(modeid);
-        mode->setRefreshRate(m.refreshRate);
+        // KWayland gives the refresh rate as int in mHz
+        mode->setRefreshRate(m.refreshRate / 1000.0);
         mode->setSize(m.size);
         mode->setName(modename);
         if (m.flags.testFlag(KWayland::Client::OutputDevice::Mode::Flag::Current)) {
@@ -189,7 +190,7 @@ QString WaylandOutput::name() const
 QDebug operator<<(QDebug dbg, const WaylandOutput *output)
 {
     dbg << "WaylandOutput(Id:" << output->id() <<", Name:" << \
-        QString(output->outputDevice()->manufacturer() + QStringLiteral(" ") + \
+        QString(output->outputDevice()->manufacturer() + QLatin1Char(' ') + \
         output->outputDevice()->model())  << ")";
     return dbg;
 }
