@@ -30,7 +30,7 @@ using namespace KScreen;
 QScreenOutput::QScreenOutput(const QScreen *qscreen, QObject *parent)
     : QObject(parent)
     , m_qscreen(qscreen)
-    , m_edid(0)
+    , m_edid(nullptr)
     , m_id(-1)
 {
 }
@@ -92,6 +92,7 @@ void QScreenOutput::updateKScreenOutput(OutputPtr &output) const
     mm.setHeight(qRound(physicalHeight));
     output->setSizeMm(mm);
     output->setPos(m_qscreen->availableGeometry().topLeft());
+    output->setSize(m_qscreen->availableGeometry().size());
 
     // Modes: we create a single default mode and go with that
     ModePtr mode(new Mode);
@@ -100,8 +101,8 @@ void QScreenOutput::updateKScreenOutput(OutputPtr &output) const
     mode->setRefreshRate(m_qscreen->refreshRate());
     mode->setSize(m_qscreen->size());
 
-    const QString modename = QString::number(m_qscreen->size().width()) + QStringLiteral("x") + QString::number(m_qscreen->size().height()) \
-                             + QStringLiteral("@") + QString::number(m_qscreen->refreshRate());
+    const QString modename = QString::number(m_qscreen->size().width()) + QLatin1String("x") + QString::number(m_qscreen->size().height()) \
+                             + QLatin1String("@") + QString::number(m_qscreen->refreshRate());
     mode->setName(modename);
 
     ModeList modes;
