@@ -1,59 +1,73 @@
-/*
- *  SPDX-FileCopyrightText: 2013 Alejandro Fiestas Olivares <afiestas@kde.org>
- *  SPDX-FileCopyrightText: 2014 Sebastian Kügler <sebas@kde.org>
- *
- *  SPDX-License-Identifier: LGPL-2.1-or-later
- */
+/*************************************************************************************
+ *  Copyright 2013 Alejandro Fiestas Olivares <afiestas@kde.org>                  *
+ *  Copyright 2014 Sebastian Kügler <sebas@kde.org>                                  *
+ *                                                                                   *
+ *  This library is free software; you can redistribute it and/or                    *
+ *  modify it under the terms of the GNU Lesser General Public                       *
+ *  License as published by the Free Software Foundation; either                     *
+ *  version 2.1 of the License, or (at your option) any later version.               *
+ *                                                                                   *
+ *  This library is distributed in the hope that it will be useful,                  *
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU                *
+ *  Lesser General Public License for more details.                                  *
+ *                                                                                   *
+ *  You should have received a copy of the GNU Lesser General Public                 *
+ *  License along with this library; if not, write to the Free Software              *
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA       *
+ *************************************************************************************/
 
 #include "testpnp.h"
 
+#include "../src/config.h"
 #include "../src/configmonitor.h"
 #include "../src/edid.h"
-#include "../src/getconfigoperation.h"
 #include "../src/mode.h"
 #include "../src/output.h"
+#include "../src/screen.h"
+#include "../src/getconfigoperation.h"
 
 #include <QGuiApplication>
 #include <QRect>
 #include <QScreen>
-#include <cstdint>
 //#include <QX11Info>
 
 using namespace KScreen;
 
-QString typetoString(const Output::Type &type)
+QString typetoString(const Output::Type& type)
 {
     switch (type) {
-    case Output::Unknown:
-        return QStringLiteral("Unknown");
-    case Output::Panel:
-        return QStringLiteral("Panel (Laptop)");
-    case Output::VGA:
-        return QStringLiteral("VGA");
-    case Output::DVII:
-        return QStringLiteral("DVI-I");
-    case Output::DVIA:
-        return QStringLiteral("DVI-A");
-    case Output::DVID:
-        return QStringLiteral("DVI-D");
-    case Output::HDMI:
-        return QStringLiteral("HDMI");
-    case Output::TV:
-        return QStringLiteral("TV");
-    case Output::TVComposite:
-        return QStringLiteral("TV-Composite");
-    case Output::TVSVideo:
-        return QStringLiteral("TV-SVideo");
-    case Output::TVComponent:
-        return QStringLiteral("TV-Component");
-    case Output::TVSCART:
-        return QStringLiteral("TV-SCART");
-    case Output::TVC4:
-        return QStringLiteral("TV-C4");
-    case Output::DisplayPort:
-        return QStringLiteral("DisplayPort");
-    default:
-        return QStringLiteral("Invalid Type");
+        case Output::Unknown:
+            return QLatin1String("Unknown");
+        case Output::Panel:
+            return QLatin1String("Panel (Laptop)");
+        case Output::VGA:
+            return QLatin1String("VGA");
+        case Output::DVII:
+            return QLatin1String("DVI-I");
+        case Output::DVIA:
+            return QLatin1String("DVI-A");
+        case Output::DVID:
+            return QLatin1String("DVI-D");
+        case Output::HDMI:
+            return QLatin1String("HDMI");
+        case Output::TV:
+            return QLatin1String("TV");
+        case Output::TVComposite:
+            return QLatin1String("TV-Composite");
+        case Output::TVSVideo:
+            return QLatin1String("TV-SVideo");
+        case Output::TVComponent:
+            return QLatin1String("TV-Component");
+        case Output::TVSCART:
+            return QLatin1String("TV-SCART");
+        case Output::TVC4:
+            return QLatin1String("TV-C4");
+        case Output::DisplayPort:
+            return QLatin1String("DisplayPort");
+        default:
+            return QLatin1String("Invalid Type");
+
     };
 }
 
@@ -70,12 +84,13 @@ TestPnp::~TestPnp()
 
 void TestPnp::init()
 {
-    connect(new KScreen::GetConfigOperation(), &KScreen::GetConfigOperation::finished, this, &TestPnp::configReady);
+    connect(new KScreen::GetConfigOperation(), &KScreen::GetConfigOperation::finished,
+            this, &TestPnp::configReady);
 }
 
 void TestPnp::configReady(KScreen::ConfigOperation *op)
 {
-    m_config = qobject_cast<KScreen::GetConfigOperation *>(op)->config();
+    m_config = qobject_cast<KScreen::GetConfigOperation*>(op)->config();
     if (!m_config) {
         qDebug() << "Config is invalid, probably backend couldn't load";
         qApp->quit();
@@ -103,7 +118,7 @@ void TestPnp::print()
     qDebug() << "\tcurrentSize:" << m_config->screen()->currentSize();
 
     const OutputList outputs = m_config->outputs();
-    for (const OutputPtr &output : outputs) {
+    Q_FOREACH(const OutputPtr &output, outputs) {
         qDebug() << "\n-----------------------------------------------------\n";
         qDebug() << "Id: " << output->id();
         qDebug() << "Name: " << output->name();
@@ -113,7 +128,7 @@ void TestPnp::print()
             continue;
         }
         qDebug() << "Enabled: " << output->isEnabled();
-        qDebug() << "Priority: " << output->priority();
+        qDebug() << "Primary: " << output->isPrimary();
         qDebug() << "Rotation: " << output->rotation();
         qDebug() << "Pos: " << output->pos();
         qDebug() << "MMSize: " << output->sizeMm();
@@ -121,8 +136,7 @@ void TestPnp::print()
             qDebug() << "Size: " << output->currentMode()->size();
         }
         if (output->clones().isEmpty()) {
-            qDebug() << "Clones: "
-                     << "None";
+            qDebug() << "Clones: " << "None";
         } else {
             qDebug() << "Clones: " << output->clones().count();
         }
@@ -132,11 +146,11 @@ void TestPnp::print()
         qDebug() << "Modes: ";
 
         const ModeList modes = output->modes();
-        for (const ModePtr &mode : modes) {
+        Q_FOREACH(const ModePtr &mode, modes) {
             qDebug() << "\t" << mode->id() << "  " << mode->name() << " " << mode->size() << " " << mode->refreshRate();
         }
 
-        const Edid *const edid = output->edid();
+        const Edid * const edid = output->edid();
         qDebug() << "EDID Info: ";
         if (edid && edid->isValid()) {
             qDebug() << "\tDevice ID: " << edid->deviceId();
